@@ -31,10 +31,10 @@ if(getRversion() >= "2.15.1") {
                            "..rel_coord","..proj_coord","..longlat","is_in_plot","tree_shape","tree_label"))
   
   # divide_plot and subplot_summary functions
-  utils::globalVariables(c("subplot_id","plot_id","subplot_ID","plot_ID","V1"))
+  utils::globalVariables(c("subplot_id","plot_id","subplot_ID","plot_ID","V1","st_crs","..col_names"))
   
   # summaryByPlot
   utils::globalVariables(c("indice_line","indice_col","Cred_2.5","Cred_97.5"))
   
   
-}
\ No newline at end of file
+}
