@@ -53,12 +53,15 @@ summaryByPlot <- function(AGB_val, plot, drawPlot = FALSE) {
 
   ##### Checking arguments -----------------------------------------------------
   if (is.list(AGB_val)) {
-    AGB_val <- AGB_val$AGB_simu
+    if(!is.null(AGB_val$AGB_simu)) { # if AGB_val is the output of AGBmonterCarlo
+      AGB_val <- AGB_val$AGB_simu
+    } else if (!is.null(AGB_val$AGB_pred)) { # in BiomassApp: AGB_val can be a list of 1 element named 'AGB_pred' and containing the output of compute_AGB() in a matrix form
+      AGB_val <- AGB_val$AGB_pred
+    }
   }
   if (!is.matrix(AGB_val) && !is.vector(AGB_val)) {
     stop(
-      "The AGB_val must be a matrix you have for the result of the function ",
-      "'AGBmonteCarlo', or just the result of the function. "
+      "AGB_val must be either the output of AGBmonteCarlo() or a matrix containing individual AGB (one row per tree)."
     )
   }
   if (length(plot) != ifelse(is.matrix(AGB_val), nrow(AGB_val), length(AGB_val))) {
@@ -93,14 +96,12 @@ summaryByPlot <- function(AGB_val, plot, drawPlot = FALSE) {
 
   ### function summary --------------------------------------------------------
 
-  mySummary <- function(x, matrix) {
+  mySummary <- function(x, matrix) { # x = row numbers of the trees for the current plot ; matrix = AGB_val
+    
+    current_plot_matrix <- as.matrix(matrix[x,]) # when summaryByPlot is called with AGB_val = computeAGB(), matrix is not a matrix anymore but a vector and we want a one-column matrix (instead of 1000 columns when AGB_val = AGBmonteCarlo()$AGB_simu)
+    
+    resAGB <- colSums(current_plot_matrix, na.rm = TRUE)
     
-    # deal with plots with only one tree individual
-    if(!is.null(nrow(matrix[x, ]))){
-    resAGB <- colSums(matrix[x, ], na.rm = TRUE)
-    }else{
-      resAGB <-matrix[x, ]
-    }
     
     # if there is trees without label
     if (nrow(indice_tree) != 0) {
@@ -131,7 +132,7 @@ summaryByPlot <- function(AGB_val, plot, drawPlot = FALSE) {
       geom_point(size=2) + 
       geom_errorbar(aes(ymin=Cred_2.5, ymax=Cred_97.5), width=.2) +
       labs(x = "", title = "AGB by plot") +
-      scale_x_discrete(breaks = AGB_plot$i, labels = AGB_plot$plot, ) +
+      scale_x_discrete(breaks = AGB_plot$i, labels = AGB_plot$plot) +
       theme_minimal())
     AGB_plot$i <- NULL
     
